"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const ern_core_1 = require("ern-core");
const getAssetsPath_1 = require("./getAssetsPath");
const fs_readdir_recursive_1 = __importDefault(require("fs-readdir-recursive"));
const path_1 = __importDefault(require("path"));
exports.supportedAssetsExts = ['.ttf', '.otf'];
/**
 * Copy in Container, the assets of all packages found in Composite,
 * that are exporting assets through react-native.config.js.
 * Similar to React Native, only fonts (.ttf/.otf) are supported for now.
 * This will copy the font assets of all packages that are either
 * dependencies:
 * https://github.com/react-native-community/cli/blob/master/docs/dependencies.md
 * or projects:
 * https://github.com/react-native-community/cli/blob/master/docs/projects.md
 */
function copyRnConfigAssets({ compositePath, outDir, platform, }) {
    return __awaiter(this, void 0, void 0, function* () {
        const dirs = yield ern_core_1.findDirectoriesHavingRnConfig(compositePath);
        for (const dir of dirs) {
            const rnConfig = require(path_1.default.join(dir, 'react-native.config.js'));
            const assets = rnConfig.assets || (rnConfig.dependency && rnConfig.dependency.assets);
            if (assets) {
                for (const assetDir of assets) {
                    const absDir = path_1.default.join(dir, assetDir);
                    fs_readdir_recursive_1.default(absDir)
                        .filter(p => {
                        return exports.supportedAssetsExts.includes(path_1.default.extname(p));
                    })
                        .map(p => path_1.default.join(assetDir, p))
                        .forEach(p => {
                        ern_core_1.handleCopyDirective(dir, outDir, [
                            { source: p, dest: getAssetsPath_1.getAssetsPath(platform, 'fonts') },
                        ]);
                    });
                }
            }
        }
    });
}
exports.copyRnConfigAssets = copyRnConfigAssets;
//# sourceMappingURL=copyRnConfigAssets.js.map