"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const sortDependenciesByName_1 = require("./sortDependenciesByName");
const bundleMiniApps_1 = require("./bundleMiniApps");
const copyRnpmAssets_1 = require("./copyRnpmAssets");
const copyRnConfigAssets_1 = require("./copyRnConfigAssets");
const addContainerMetadata_1 = require("./addContainerMetadata");
const ern_core_1 = require("ern-core");
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const lodash_1 = __importDefault(require("lodash"));
function generateContainer(config, { fillContainerHull, postCopyRnpmAssets, } = {}) {
    return __awaiter(this, void 0, void 0, function* () {
        if (!fs_1.default.existsSync(config.outDir)) {
            ern_core_1.shell.mkdir('-p', config.outDir);
        }
        else {
            ern_core_1.shell.rm('-rf', path_1.default.join(config.outDir, '{.*,*}'));
        }
        config.plugins = sortDependenciesByName_1.sortDependenciesByName(config.plugins);
        const reactNativePlugin = lodash_1.default.find(config.plugins, p => p.basePath === 'react-native');
        // React-native plugin should be first in the dependencies
        // Otherwise any module dependent on r-n won't be able to use it
        config.plugins = [
            ...(reactNativePlugin ? [reactNativePlugin] : []),
            ...config.plugins.filter(plugin => plugin !== reactNativePlugin),
        ];
        ern_core_1.shell.pushd(config.outDir);
        try {
            if (fillContainerHull) {
                yield fillContainerHull(config);
            }
        }
        finally {
            ern_core_1.shell.popd();
        }
        const bundlingResult = yield ern_core_1.kax
            .task('Bundling MiniApps')
            .run(bundleMiniApps_1.bundleMiniAppsFromComposite({
            compositeDir: config.composite.path,
            outDir: config.outDir,
            platform: config.targetPlatform,
            sourceMapOutput: config.sourceMapOutput,
        }));
        if (!config.ignoreRnpmAssets) {
            copyRnpmAssets_1.copyRnpmAssets(config.composite.getMiniApps(), config.composite.path, config.outDir, config.targetPlatform);
            yield copyRnConfigAssets_1.copyRnConfigAssets({
                compositePath: config.composite.path,
                outDir: config.outDir,
                platform: config.targetPlatform,
            });
            if (postCopyRnpmAssets) {
                yield postCopyRnpmAssets(config);
            }
        }
        yield ern_core_1.kax
            .task('Adding Electrode Native Metadata File')
            .run(addContainerMetadata_1.addContainerMetadata(config));
        return {
            bundlingResult,
            config,
        };
    });
}
exports.generateContainer = generateContainer;
//# sourceMappingURL=generateContainer.js.map