"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ern_core_1 = require("ern-core");
/**
 *
 * @param apiImplPluginPath : node package directory from for the api impl module.
 * @param mustacheView: Object
 * @param excludeJsImpl: setting this to true will exclude api details for a JS implementation.
 * @param excludeNativeImpl: setting this to true will exclude api details for a native implementation.
 */
function populateApiImplMustacheView(apiImplPluginPath, mustacheView = {}, excludeJsImpl, excludeNativeImpl) {
    const packageJson = ern_core_1.readPackageJsonSync(apiImplPluginPath);
    const containerGenConfig = packageJson.ern.containerGen;
    if (containerGenConfig && containerGenConfig.apiNames) {
        mustacheView.apiImplementations = mustacheView.apiImplementations
            ? mustacheView.apiImplementations
            : [];
        for (const apiName of containerGenConfig.apiNames) {
            if (excludeJsImpl &&
                packageJson.ern.moduleType === ern_core_1.ModuleTypes.JS_API_IMPL) {
                continue;
            }
            if (excludeNativeImpl &&
                packageJson.ern.moduleType === ern_core_1.ModuleTypes.NATIVE_API_IMPL) {
                continue;
            }
            const api = {
                apiName,
                apiVariableName: ern_core_1.utils.camelize(apiName, true),
                hasConfig: containerGenConfig.hasConfig,
            };
            mustacheView.apiImplementations.push(api);
        }
    }
    else {
        ern_core_1.log.warn(`!!!!! containerGen entry not valid for api implementation, skipping api-impl code gen in container for ${packageJson.name} !!!!`);
    }
}
exports.populateApiImplMustacheView = populateApiImplMustacheView;
//# sourceMappingURL=populateApiImplMustacheView.js.map